pub enum Error {
DomainError(String),
UnexpectedResponse,
Reqwest(Error),
}Expand description
Error returned by throttle client library.
Variants
DomainError(String)
Errors of this kind should not be able to occur during normal operations. They hint at either coding error or a wrong configuration. An example would be requesting a lock to a non-existing semaphore.
UnexpectedResponse
The server did answer with something unexpected for a throttle servers.
Reqwest(Error)